Your message dated Thu, 04 Dec 2008 13:02:03 +0000
with message-id <[EMAIL PROTECTED]>
and subject line Bug#506740: fixed in wbxml2 0.9.2-7
has caused the Debian Bug report #506740,
regarding libwbxml2-0: SyncML with embedded DevInf has wrong DevInf version
to be marked as done.
This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.
(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact [EMAIL PROTECTED]
immediately.)
--
506740: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=506740
Debian Bug Tracking System
Contact [EMAIL PROTECTED] with problems
--- Begin Message ---
Package: libwbxml2-0
Version: 0.9.2-6
Severity: normal
SyncML sometimes need to embed the device information into a message.
The device information is an own document. The actual package always
embeds the device information document with version 1.2. The
resulting document is simply wrong if the wrapping document is not
SyncML 1.2.
Several devices like all actual Nokia S40 models and several Sony-Ericsson
mobiles with the proprietary OS from Sony-Ericsson fail on such
documents. This means that the library does not work for more than 50
percent of the potentially usable mobiles. So the severity of this bug
is serious.
Please notice that reportbug downgraded the severity automatically
because I don't know the Debian policy manual section IDs.
The attached patch fixes the problem and sets the DevInf version
according to the version of the wrapping SyncML message.
-- System Information:
Debian Release: lenny/sid
APT prefers unstable
APT policy: (500, 'unstable'), (1, 'experimental')
Architecture: i386 (i686)
Kernel: Linux 2.6.25-2-686 (SMP w/1 CPU core)
Locale: LANG=en_US.UTF-8, LC_CTYPE=en_US.UTF-8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/bash
Versions of packages libwbxml2-0 depends on:
ii libc6 2.7-11 GNU C Library: Shared libraries
ii libexpat1 1.95.8-4 XML parsing C library - runtime li
ii libpopt0 1.14-4 lib for parsing cmdline parameters
ii zlib1g 1:1.2.3.3.dfsg-12 compression library - runtime
libwbxml2-0 recommends no packages.
-- no debconf information
--- src/wbxml_tree_clb_xml.c.orig 2008-11-18 13:19:11.000000000 +0100
+++ src/wbxml_tree_clb_xml.c 2008-11-18 14:07:58.000000000 +0100
@@ -210,15 +210,41 @@
return;
}
- /* Add doctype to give the XML parser a chance
- * SyncML 1.2 is downward compatible to older versions.
- */
- if (!wbxml_buffer_insert_cstr(devinf_doc, "<!DOCTYPE DevInf PUBLIC '-//SYNCML//DTD DevInf 1.2//EN' 'http://www.openmobilealliance.org/tech/DTD/OMA-SyncML-Device_Information-DTD-1.2.dtd' >\n", 0))
- {
- tree_ctx->error = WBXML_ERROR_NOT_ENOUGH_MEMORY;
- wbxml_buffer_destroy(devinf_doc);
- return;
- }
+ /* Add doctype to give the XML parser a chance */
+ const WBXMLLangEntry *lang;
+ switch(tree_ctx->tree->lang->langID)
+ {
+ case WBXML_LANG_SYNCML_SYNCML10:
+ lang = wbxml_tables_get_table(WBXML_LANG_SYNCML_DEVINF10);
+ break;
+ case WBXML_LANG_SYNCML_SYNCML11:
+ lang = wbxml_tables_get_table(WBXML_LANG_SYNCML_DEVINF11);
+ break;
+ case WBXML_LANG_SYNCML_SYNCML12:
+ lang = wbxml_tables_get_table(WBXML_LANG_SYNCML_DEVINF12);
+ break;
+ default:
+ tree_ctx->error = WBXML_ERROR_UNKNOWN_XML_LANGUAGE;
+ return;
+ }
+ WBXMLBuffer *buffer = wbxml_buffer_create(NULL, 0, 0);
+ if (!buffer) {
+ tree_ctx->error = WBXML_ERROR_NOT_ENOUGH_MEMORY;
+ return;
+ }
+ /* DOCTYPE in reverse order */
+ if (!wbxml_buffer_insert_cstr(devinf_doc, "\">\n", 0) || /* > */
+ !wbxml_buffer_insert_cstr(devinf_doc, lang->publicID->xmlDTD, 0) || /* DTD */
+ !wbxml_buffer_insert_cstr(devinf_doc, "\" \"", 0) || /* DTD */
+ !wbxml_buffer_insert_cstr(devinf_doc, lang->publicID->xmlPublicID, 0) || /* Public ID */
+ !wbxml_buffer_insert_cstr(devinf_doc, " PUBLIC \"", 0) || /* PUBLIC " */
+ !wbxml_buffer_insert_cstr(devinf_doc, lang->publicID->xmlRootElt, 0) || /* Root Element */
+ !wbxml_buffer_insert_cstr(devinf_doc, "<!DOCTYPE ", 0)) /* <!DOCTYPE */
+ {
+ tree_ctx->error = WBXML_ERROR_ENCODER_APPEND_DATA;
+ wbxml_buffer_destroy(devinf_doc);
+ return;
+ }
WBXML_DEBUG((WBXML_PARSER, "\t DevInf Doc : '%s'", wbxml_buffer_get_cstr(devinf_doc)));
--- End Message ---
--- Begin Message ---
Source: wbxml2
Source-Version: 0.9.2-7
We believe that the bug you reported is fixed in the latest version of
wbxml2, which is due to be installed in the Debian FTP archive:
libwbxml2-0-dbg_0.9.2-7_i386.deb
to pool/main/w/wbxml2/libwbxml2-0-dbg_0.9.2-7_i386.deb
libwbxml2-0_0.9.2-7_i386.deb
to pool/main/w/wbxml2/libwbxml2-0_0.9.2-7_i386.deb
libwbxml2-dev_0.9.2-7_i386.deb
to pool/main/w/wbxml2/libwbxml2-dev_0.9.2-7_i386.deb
libwbxml2-utils_0.9.2-7_i386.deb
to pool/main/w/wbxml2/libwbxml2-utils_0.9.2-7_i386.deb
wbxml2_0.9.2-7.diff.gz
to pool/main/w/wbxml2/wbxml2_0.9.2-7.diff.gz
wbxml2_0.9.2-7.dsc
to pool/main/w/wbxml2/wbxml2_0.9.2-7.dsc
A summary of the changes between this version and the previous one is
attached.
Thank you for reporting the bug, which will now be closed. If you
have further comments please address them to [EMAIL PROTECTED],
and the maintainer will reopen the bug report if appropriate.
Debian distribution maintenance software
pp.
Michael Banck <[EMAIL PROTECTED]> (supplier of updated wbxml2 package)
(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing [EMAIL PROTECTED])
-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1
Format: 1.8
Date: Thu, 04 Dec 2008 13:42:44 +0100
Source: wbxml2
Binary: libwbxml2-dev libwbxml2-0-dbg libwbxml2-0 libwbxml2-utils
Architecture: source i386
Version: 0.9.2-7
Distribution: unstable
Urgency: high
Maintainer: Michael Banck <[EMAIL PROTECTED]>
Changed-By: Michael Banck <[EMAIL PROTECTED]>
Description:
libwbxml2-0 - WBXML parsing and encoding library
libwbxml2-0-dbg - WBXML library development file
libwbxml2-dev - WBXML library development file
libwbxml2-utils - Binary XML utilities
Closes: 506740 507689
Changes:
wbxml2 (0.9.2-7) unstable; urgency=high
.
* Urgency `high' due to RC bug fix.
* debian/patches/09-devinf-doctype.patch: New patch, no longer hardcodes the
Syncml version in the device information document, by Michael Bell;
closes: #506740.
* debian/patches/10-fix-wbxml-public-ids.patch: New patch, swaps the
WBXML_PUBLIC_ID_SYNCML_METINF12 and WBXML_PUBLIC_ID_SYNCML_DEVINF12
values to be in line with the OMNA standard; closes: #507689.
Checksums-Sha1:
70245952529813fb6946f47c26de5ea4d0b21da8 1120 wbxml2_0.9.2-7.dsc
3b6bb8e117cda04c99dd120f2e3484c77aca0ee8 11559 wbxml2_0.9.2-7.diff.gz
d52a2fc4710816d2c59bc4e124e1d7914765e242 91266 libwbxml2-dev_0.9.2-7_i386.deb
1c550ae2ca593e5ba053a9b2f9ec2c07fb1c232a 88564 libwbxml2-0-dbg_0.9.2-7_i386.deb
3a067fd07a6391d54db18e653cca1c4d7615a3a7 67478 libwbxml2-0_0.9.2-7_i386.deb
0559099f5f4267549aeff470d2fc2ebd63e39126 21478 libwbxml2-utils_0.9.2-7_i386.deb
Checksums-Sha256:
e08e850c290bb89ed82b32c751c03ddd0b200925bf6b1311f02f74d2dc19db6e 1120
wbxml2_0.9.2-7.dsc
246750b0f273ce7487247d8256e00e170a4726f247377b3e2a57448fb8aa9da1 11559
wbxml2_0.9.2-7.diff.gz
3aa7fa8595086f6be8a30c9a8693f6ccd287b5dba0b20ea35d011c23111df7db 91266
libwbxml2-dev_0.9.2-7_i386.deb
741f09efdf9fb88c9072f42dec86041a2ac364b2976cadcb8d89e3e6c92f1a2b 88564
libwbxml2-0-dbg_0.9.2-7_i386.deb
16283c51f246e6cb8c83bc054de279d08a6b99bc114960d8f1c765f1d3b9a911 67478
libwbxml2-0_0.9.2-7_i386.deb
713a71777bee9e9f4e38fe4bdf3ca92a07f99dd22f23dafcbcee3f17494597fe 21478
libwbxml2-utils_0.9.2-7_i386.deb
Files:
5f1aeb2c52f9275921b3800a02dff9e1 1120 libs optional wbxml2_0.9.2-7.dsc
3c0852b347db1eeada9d732d71ef8194 11559 libs optional wbxml2_0.9.2-7.diff.gz
d25da5b29519051abbf29528b557b7c8 91266 libdevel optional
libwbxml2-dev_0.9.2-7_i386.deb
823e20301fc0fe03d23c7d8cfa524fda 88564 libdevel extra
libwbxml2-0-dbg_0.9.2-7_i386.deb
d3df66216fdad101e734180e89f91ec5 67478 libs optional
libwbxml2-0_0.9.2-7_i386.deb
986ef686790a41a68bce3a698ab46088 21478 text optional
libwbxml2-utils_0.9.2-7_i386.deb
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.2.1 (GNU/Linux)
iD8DBQFJN9FTmHaJYZ7RAb8RAlmiAKCAN0jGafxN8KOycmyqrTOjr873TQCgipK1
27RvRIX7oBQzxiO+Kqxw4mE=
=ZyNV
-----END PGP SIGNATURE-----
--- End Message ---